fiveesrd_models library
Core data models (REST + GraphQL) shared by the FiveEsrd package suite.
Classes
- AbilityBonus
- AbilityScore
- AbilityScoreNode
- AbilityScoresResponse
- Alignment
- APIReference
- APIReferenceList
- AreaOfEffect
- Armor
- Background
- Background$Feature
- Choice
- Class
- Class$StartingEquipment$Item
- ClassLevel
- ClassLevel$Spellcasting
- ClassLevelSpell
- ClassSpellList
- Condition
- Cost
- Damage
- DamageAtCharacterLevel
- DamageAtSlotLevel
- DamageType
- Dc
- Equipment
- Union type representing equipment items that can be Weapon, Armor, or Gear.
- EquipmentCategory
- EquipmentPack
- ErrorResponse
- Feat
- Feature
- Gear
- GraphQlMonsterSpecialAbility
- Language
- MagicItem
- MagicItem$Rarity
- MagicSchool
- Monster
- Monster$Speed
- MonsterAbility
- MonsterAction
- MonsterArmorClass
- MonsterArmorClassEntry
- MonsterAttack
- MonsterDetail
- MonsterDetailResponse
- MonsterMultiAttackAction
- MonsterProficiency
- MonsterProficiencyNode
- MonsterSense
- MonsterSenses
- MonstersOverviewResponse
- MonsterSpecialAbility
- MonsterSpeedModel
- MonsterSpell
- MonsterSpellcasting
- MonsterSummary
- MonsterUsage
- Multiclassing
- NamedApiResource
- Option
- OptionSet
- Prerequisite
- Proficiency
- Race
- ResourceDescription
- Rule
- RuleSection
- Skill
- Spell
- Spellcasting
- Spellcasting$Info$Item
- SpellPrerequisite
- Subclass
- Subclass$Spells$Item
- SubclassLevel
- SubclassLevel$Spellcasting
- SubclassLevelResource
- Subrace
- SwaggerMetaData
- Metadata class containing information from SwaggerRequest
- Trait
- Weapon
- Weapon$Range
- WeaponProperty
-
Wrapped<
T>
Enums
- AbilityScoreIndex
- AlignmentIndex
- Api2014FeatsIndexGetIndex
- AreaOfEffectType
- BackgroundIndex
- BaseEndpointIndex
- ClassIndex
- ConditionIndex
- DamageTypeIndex
- LanguageIndex
- LanguageType
- MagicItem$RarityName
- MagicSchoolIndex
- MonsterMultiAttackActionType
- MonsterSize
- MonsterUsageType
- RaceIndex
- RuleIndex
- RuleSectionIndex
- SkillIndex
- SpellComponents
- SrdVersion
- Represents the supported SRD dataset versions published by Wizards of the Coast.
- SubclassIndex
- SubraceIndex
- TraitIndex
- WeaponPropertyIndex
Extensions
- $AbilityBonusExtension on AbilityBonus
- $AbilityScoreExtension on AbilityScore
- $AlignmentExtension on Alignment
- $APIReferenceExtension on APIReference
- $APIReferenceListExtension on APIReferenceList
- $AreaOfEffectExtension on AreaOfEffect
- $ArmorExtension on Armor
- $Background$FeatureExtension on Background$Feature
- $BackgroundExtension on Background
- $ChoiceExtension on Choice
- $Class$StartingEquipment$ItemExtension on Class$StartingEquipment$Item
- $ClassExtension on Class
- $ClassLevel$SpellcastingExtension on ClassLevel$Spellcasting
- $ClassLevelExtension on ClassLevel
- $ClassLevelSpellExtension on ClassLevelSpell
- $ClassSpellListExtension on ClassSpellList
- $ConditionExtension on Condition
- $CostExtension on Cost
- $DamageAtCharacterLevelExtension on DamageAtCharacterLevel
- $DamageAtSlotLevelExtension on DamageAtSlotLevel
- $DamageExtension on Damage
- $DamageTypeExtension on DamageType
- $DcExtension on Dc
- $EquipmentCategoryExtension on EquipmentCategory
- $EquipmentPackExtension on EquipmentPack
- $ErrorResponseExtension on ErrorResponse
- $FeatExtension on Feat
- $FeatureExtension on Feature
- $GearExtension on Gear
- $LanguageExtension on Language
- $MagicItem$RarityExtension on MagicItem$Rarity
- $MagicItemExtension on MagicItem
- $MagicSchoolExtension on MagicSchool
- $Monster$SpeedExtension on Monster$Speed
- $MonsterAbilityExtension on MonsterAbility
- $MonsterActionExtension on MonsterAction
- $MonsterAttackExtension on MonsterAttack
- $MonsterExtension on Monster
- $MonsterMultiAttackActionExtension on MonsterMultiAttackAction
- $MonsterProficiencyExtension on MonsterProficiency
- $MonsterSenseExtension on MonsterSense
- $MonsterSpecialAbilityExtension on MonsterSpecialAbility
- $MonsterSpellcastingExtension on MonsterSpellcasting
- $MonsterSpellExtension on MonsterSpell
- $MonsterUsageExtension on MonsterUsage
- $MulticlassingExtension on Multiclassing
- $PrerequisiteExtension on Prerequisite
- $ProficiencyExtension on Proficiency
- $RaceExtension on Race
- $ResourceDescriptionExtension on ResourceDescription
- $RuleExtension on Rule
- $RuleSectionExtension on RuleSection
- $SkillExtension on Skill
- $Spellcasting$Info$ItemExtension on Spellcasting$Info$Item
- $SpellcastingExtension on Spellcasting
- $SpellExtension on Spell
- $SpellPrerequisiteExtension on SpellPrerequisite
- $Subclass$Spells$ItemExtension on Subclass$Spells$Item
- $SubclassExtension on Subclass
- $SubclassLevel$SpellcastingExtension on SubclassLevel$Spellcasting
- $SubclassLevelExtension on SubclassLevel
- $SubclassLevelResourceExtension on SubclassLevelResource
- $SubraceExtension on Subrace
- $TraitExtension on Trait
- $Weapon$RangeExtension on Weapon$Range
- $WeaponExtension on Weapon
- $WeaponPropertyExtension on WeaponProperty
- SrdVersionX on SrdVersion
Functions
-
abilityScoreIndexExplodedListToJson(
List< AbilityScoreIndex> ? abilityScoreIndex) → String -
abilityScoreIndexFromJson(
Object? abilityScoreIndex, [AbilityScoreIndex? defaultValue]) → AbilityScoreIndex -
abilityScoreIndexListFromJson(
List? abilityScoreIndex, [List< AbilityScoreIndex> ? defaultValue]) → List<AbilityScoreIndex> -
abilityScoreIndexListToJson(
List< AbilityScoreIndex> ? abilityScoreIndex) → List<String> -
abilityScoreIndexNullableFromJson(
Object? abilityScoreIndex, [AbilityScoreIndex? defaultValue]) → AbilityScoreIndex? -
abilityScoreIndexNullableListFromJson(
List? abilityScoreIndex, [List< AbilityScoreIndex> ? defaultValue]) → List<AbilityScoreIndex> ? -
abilityScoreIndexNullableToJson(
AbilityScoreIndex? abilityScoreIndex) → String? -
abilityScoreIndexToJson(
AbilityScoreIndex abilityScoreIndex) → String? -
alignmentIndexExplodedListToJson(
List< AlignmentIndex> ? alignmentIndex) → String -
alignmentIndexFromJson(
Object? alignmentIndex, [AlignmentIndex? defaultValue]) → AlignmentIndex -
alignmentIndexListFromJson(
List? alignmentIndex, [List< AlignmentIndex> ? defaultValue]) → List<AlignmentIndex> -
alignmentIndexListToJson(
List< AlignmentIndex> ? alignmentIndex) → List<String> -
alignmentIndexNullableFromJson(
Object? alignmentIndex, [AlignmentIndex? defaultValue]) → AlignmentIndex? -
alignmentIndexNullableListFromJson(
List? alignmentIndex, [List< AlignmentIndex> ? defaultValue]) → List<AlignmentIndex> ? -
alignmentIndexNullableToJson(
AlignmentIndex? alignmentIndex) → String? -
alignmentIndexToJson(
AlignmentIndex alignmentIndex) → String? -
api2014FeatsIndexGetIndexExplodedListToJson(
List< Api2014FeatsIndexGetIndex> ? api2014FeatsIndexGetIndex) → String -
api2014FeatsIndexGetIndexFromJson(
Object? api2014FeatsIndexGetIndex, [Api2014FeatsIndexGetIndex? defaultValue]) → Api2014FeatsIndexGetIndex -
api2014FeatsIndexGetIndexListFromJson(
List? api2014FeatsIndexGetIndex, [List< Api2014FeatsIndexGetIndex> ? defaultValue]) → List<Api2014FeatsIndexGetIndex> -
api2014FeatsIndexGetIndexListToJson(
List< Api2014FeatsIndexGetIndex> ? api2014FeatsIndexGetIndex) → List<String> -
api2014FeatsIndexGetIndexNullableFromJson(
Object? api2014FeatsIndexGetIndex, [Api2014FeatsIndexGetIndex? defaultValue]) → Api2014FeatsIndexGetIndex? -
api2014FeatsIndexGetIndexNullableListFromJson(
List? api2014FeatsIndexGetIndex, [List< Api2014FeatsIndexGetIndex> ? defaultValue]) → List<Api2014FeatsIndexGetIndex> ? -
api2014FeatsIndexGetIndexNullableToJson(
Api2014FeatsIndexGetIndex? api2014FeatsIndexGetIndex) → String? -
api2014FeatsIndexGetIndexToJson(
Api2014FeatsIndexGetIndex api2014FeatsIndexGetIndex) → String? -
areaOfEffectTypeExplodedListToJson(
List< AreaOfEffectType> ? areaOfEffectType) → String -
areaOfEffectTypeFromJson(
Object? areaOfEffectType, [AreaOfEffectType? defaultValue]) → AreaOfEffectType -
areaOfEffectTypeListFromJson(
List? areaOfEffectType, [List< AreaOfEffectType> ? defaultValue]) → List<AreaOfEffectType> -
areaOfEffectTypeListToJson(
List< AreaOfEffectType> ? areaOfEffectType) → List<String> -
areaOfEffectTypeNullableFromJson(
Object? areaOfEffectType, [AreaOfEffectType? defaultValue]) → AreaOfEffectType? -
areaOfEffectTypeNullableListFromJson(
List? areaOfEffectType, [List< AreaOfEffectType> ? defaultValue]) → List<AreaOfEffectType> ? -
areaOfEffectTypeNullableToJson(
AreaOfEffectType? areaOfEffectType) → String? -
areaOfEffectTypeToJson(
AreaOfEffectType areaOfEffectType) → String? -
backgroundIndexExplodedListToJson(
List< BackgroundIndex> ? backgroundIndex) → String -
backgroundIndexFromJson(
Object? backgroundIndex, [BackgroundIndex? defaultValue]) → BackgroundIndex -
backgroundIndexListFromJson(
List? backgroundIndex, [List< BackgroundIndex> ? defaultValue]) → List<BackgroundIndex> -
backgroundIndexListToJson(
List< BackgroundIndex> ? backgroundIndex) → List<String> -
backgroundIndexNullableFromJson(
Object? backgroundIndex, [BackgroundIndex? defaultValue]) → BackgroundIndex? -
backgroundIndexNullableListFromJson(
List? backgroundIndex, [List< BackgroundIndex> ? defaultValue]) → List<BackgroundIndex> ? -
backgroundIndexNullableToJson(
BackgroundIndex? backgroundIndex) → String? -
backgroundIndexToJson(
BackgroundIndex backgroundIndex) → String? -
baseEndpointIndexExplodedListToJson(
List< BaseEndpointIndex> ? baseEndpointIndex) → String -
baseEndpointIndexFromJson(
Object? baseEndpointIndex, [BaseEndpointIndex? defaultValue]) → BaseEndpointIndex -
baseEndpointIndexListFromJson(
List? baseEndpointIndex, [List< BaseEndpointIndex> ? defaultValue]) → List<BaseEndpointIndex> -
baseEndpointIndexListToJson(
List< BaseEndpointIndex> ? baseEndpointIndex) → List<String> -
baseEndpointIndexNullableFromJson(
Object? baseEndpointIndex, [BaseEndpointIndex? defaultValue]) → BaseEndpointIndex? -
baseEndpointIndexNullableListFromJson(
List? baseEndpointIndex, [List< BaseEndpointIndex> ? defaultValue]) → List<BaseEndpointIndex> ? -
baseEndpointIndexNullableToJson(
BaseEndpointIndex? baseEndpointIndex) → String? -
baseEndpointIndexToJson(
BaseEndpointIndex baseEndpointIndex) → String? -
classIndexExplodedListToJson(
List< ClassIndex> ? classIndex) → String -
classIndexFromJson(
Object? classIndex, [ClassIndex? defaultValue]) → ClassIndex -
classIndexListFromJson(
List? classIndex, [List< ClassIndex> ? defaultValue]) → List<ClassIndex> -
classIndexListToJson(
List< ClassIndex> ? classIndex) → List<String> -
classIndexNullableFromJson(
Object? classIndex, [ClassIndex? defaultValue]) → ClassIndex? -
classIndexNullableListFromJson(
List? classIndex, [List< ClassIndex> ? defaultValue]) → List<ClassIndex> ? -
classIndexNullableToJson(
ClassIndex? classIndex) → String? -
classIndexToJson(
ClassIndex classIndex) → String? -
conditionIndexExplodedListToJson(
List< ConditionIndex> ? conditionIndex) → String -
conditionIndexFromJson(
Object? conditionIndex, [ConditionIndex? defaultValue]) → ConditionIndex -
conditionIndexListFromJson(
List? conditionIndex, [List< ConditionIndex> ? defaultValue]) → List<ConditionIndex> -
conditionIndexListToJson(
List< ConditionIndex> ? conditionIndex) → List<String> -
conditionIndexNullableFromJson(
Object? conditionIndex, [ConditionIndex? defaultValue]) → ConditionIndex? -
conditionIndexNullableListFromJson(
List? conditionIndex, [List< ConditionIndex> ? defaultValue]) → List<ConditionIndex> ? -
conditionIndexNullableToJson(
ConditionIndex? conditionIndex) → String? -
conditionIndexToJson(
ConditionIndex conditionIndex) → String? -
damageTypeIndexExplodedListToJson(
List< DamageTypeIndex> ? damageTypeIndex) → String -
damageTypeIndexFromJson(
Object? damageTypeIndex, [DamageTypeIndex? defaultValue]) → DamageTypeIndex -
damageTypeIndexListFromJson(
List? damageTypeIndex, [List< DamageTypeIndex> ? defaultValue]) → List<DamageTypeIndex> -
damageTypeIndexListToJson(
List< DamageTypeIndex> ? damageTypeIndex) → List<String> -
damageTypeIndexNullableFromJson(
Object? damageTypeIndex, [DamageTypeIndex? defaultValue]) → DamageTypeIndex? -
damageTypeIndexNullableListFromJson(
List? damageTypeIndex, [List< DamageTypeIndex> ? defaultValue]) → List<DamageTypeIndex> ? -
damageTypeIndexNullableToJson(
DamageTypeIndex? damageTypeIndex) → String? -
damageTypeIndexToJson(
DamageTypeIndex damageTypeIndex) → String? -
languageIndexExplodedListToJson(
List< LanguageIndex> ? languageIndex) → String -
languageIndexFromJson(
Object? languageIndex, [LanguageIndex? defaultValue]) → LanguageIndex -
languageIndexListFromJson(
List? languageIndex, [List< LanguageIndex> ? defaultValue]) → List<LanguageIndex> -
languageIndexListToJson(
List< LanguageIndex> ? languageIndex) → List<String> -
languageIndexNullableFromJson(
Object? languageIndex, [LanguageIndex? defaultValue]) → LanguageIndex? -
languageIndexNullableListFromJson(
List? languageIndex, [List< LanguageIndex> ? defaultValue]) → List<LanguageIndex> ? -
languageIndexNullableToJson(
LanguageIndex? languageIndex) → String? -
languageIndexToJson(
LanguageIndex languageIndex) → String? -
languageTypeExplodedListToJson(
List< LanguageType> ? languageType) → String -
languageTypeFromJson(
Object? languageType, [LanguageType? defaultValue]) → LanguageType -
languageTypeListFromJson(
List? languageType, [List< LanguageType> ? defaultValue]) → List<LanguageType> -
languageTypeListToJson(
List< LanguageType> ? languageType) → List<String> -
languageTypeNullableFromJson(
Object? languageType, [LanguageType? defaultValue]) → LanguageType? -
languageTypeNullableListFromJson(
List? languageType, [List< LanguageType> ? defaultValue]) → List<LanguageType> ? -
languageTypeNullableToJson(
LanguageType? languageType) → String? -
languageTypeToJson(
LanguageType languageType) → String? -
magicItem$RarityNameExplodedListToJson(
List< MagicItem$RarityName> ? magicItem$RarityName) → String -
magicItem$RarityNameFromJson(
Object? magicItem$RarityName, [MagicItem$RarityName? defaultValue]) → MagicItem$RarityName -
magicItem$RarityNameListFromJson(
List? magicItem$RarityName, [List< MagicItem$RarityName> ? defaultValue]) → List<MagicItem$RarityName> -
magicItem$RarityNameListToJson(
List< MagicItem$RarityName> ? magicItem$RarityName) → List<String> -
magicItem$RarityNameNullableFromJson(
Object? magicItem$RarityName, [MagicItem$RarityName? defaultValue]) → MagicItem$RarityName? -
magicItem$RarityNameNullableListFromJson(
List? magicItem$RarityName, [List< MagicItem$RarityName> ? defaultValue]) → List<MagicItem$RarityName> ? -
magicItem$RarityNameNullableToJson(
MagicItem$RarityName? magicItem$RarityName) → String? -
magicItem$RarityNameToJson(
MagicItem$RarityName magicItem$RarityName) → String? -
magicSchoolIndexExplodedListToJson(
List< MagicSchoolIndex> ? magicSchoolIndex) → String -
magicSchoolIndexFromJson(
Object? magicSchoolIndex, [MagicSchoolIndex? defaultValue]) → MagicSchoolIndex -
magicSchoolIndexListFromJson(
List? magicSchoolIndex, [List< MagicSchoolIndex> ? defaultValue]) → List<MagicSchoolIndex> -
magicSchoolIndexListToJson(
List< MagicSchoolIndex> ? magicSchoolIndex) → List<String> -
magicSchoolIndexNullableFromJson(
Object? magicSchoolIndex, [MagicSchoolIndex? defaultValue]) → MagicSchoolIndex? -
magicSchoolIndexNullableListFromJson(
List? magicSchoolIndex, [List< MagicSchoolIndex> ? defaultValue]) → List<MagicSchoolIndex> ? -
magicSchoolIndexNullableToJson(
MagicSchoolIndex? magicSchoolIndex) → String? -
magicSchoolIndexToJson(
MagicSchoolIndex magicSchoolIndex) → String? -
monsterMultiAttackActionTypeExplodedListToJson(
List< MonsterMultiAttackActionType> ? monsterMultiAttackActionType) → String -
monsterMultiAttackActionTypeFromJson(
Object? monsterMultiAttackActionType, [MonsterMultiAttackActionType? defaultValue]) → MonsterMultiAttackActionType -
monsterMultiAttackActionTypeListFromJson(
List? monsterMultiAttackActionType, [List< MonsterMultiAttackActionType> ? defaultValue]) → List<MonsterMultiAttackActionType> -
monsterMultiAttackActionTypeListToJson(
List< MonsterMultiAttackActionType> ? monsterMultiAttackActionType) → List<String> -
monsterMultiAttackActionTypeNullableFromJson(
Object? monsterMultiAttackActionType, [MonsterMultiAttackActionType? defaultValue]) → MonsterMultiAttackActionType? -
monsterMultiAttackActionTypeNullableListFromJson(
List? monsterMultiAttackActionType, [List< MonsterMultiAttackActionType> ? defaultValue]) → List<MonsterMultiAttackActionType> ? -
monsterMultiAttackActionTypeNullableToJson(
MonsterMultiAttackActionType? monsterMultiAttackActionType) → String? -
monsterMultiAttackActionTypeToJson(
MonsterMultiAttackActionType monsterMultiAttackActionType) → String? -
monsterSizeExplodedListToJson(
List< MonsterSize> ? monsterSize) → String -
monsterSizeFromJson(
Object? monsterSize, [MonsterSize? defaultValue]) → MonsterSize -
monsterSizeListFromJson(
List? monsterSize, [List< MonsterSize> ? defaultValue]) → List<MonsterSize> -
monsterSizeListToJson(
List< MonsterSize> ? monsterSize) → List<String> -
monsterSizeNullableFromJson(
Object? monsterSize, [MonsterSize? defaultValue]) → MonsterSize? -
monsterSizeNullableListFromJson(
List? monsterSize, [List< MonsterSize> ? defaultValue]) → List<MonsterSize> ? -
monsterSizeNullableToJson(
MonsterSize? monsterSize) → String? -
monsterSizeToJson(
MonsterSize monsterSize) → String? -
monsterUsageTypeExplodedListToJson(
List< MonsterUsageType> ? monsterUsageType) → String -
monsterUsageTypeFromJson(
Object? monsterUsageType, [MonsterUsageType? defaultValue]) → MonsterUsageType -
monsterUsageTypeListFromJson(
List? monsterUsageType, [List< MonsterUsageType> ? defaultValue]) → List<MonsterUsageType> -
monsterUsageTypeListToJson(
List< MonsterUsageType> ? monsterUsageType) → List<String> -
monsterUsageTypeNullableFromJson(
Object? monsterUsageType, [MonsterUsageType? defaultValue]) → MonsterUsageType? -
monsterUsageTypeNullableListFromJson(
List? monsterUsageType, [List< MonsterUsageType> ? defaultValue]) → List<MonsterUsageType> ? -
monsterUsageTypeNullableToJson(
MonsterUsageType? monsterUsageType) → String? -
monsterUsageTypeToJson(
MonsterUsageType monsterUsageType) → String? -
raceIndexExplodedListToJson(
List< RaceIndex> ? raceIndex) → String -
raceIndexFromJson(
Object? raceIndex, [RaceIndex? defaultValue]) → RaceIndex -
raceIndexListFromJson(
List? raceIndex, [List< RaceIndex> ? defaultValue]) → List<RaceIndex> -
raceIndexListToJson(
List< RaceIndex> ? raceIndex) → List<String> -
raceIndexNullableFromJson(
Object? raceIndex, [RaceIndex? defaultValue]) → RaceIndex? -
raceIndexNullableListFromJson(
List? raceIndex, [List< RaceIndex> ? defaultValue]) → List<RaceIndex> ? -
raceIndexNullableToJson(
RaceIndex? raceIndex) → String? -
raceIndexToJson(
RaceIndex raceIndex) → String? -
ruleIndexExplodedListToJson(
List< RuleIndex> ? ruleIndex) → String -
ruleIndexFromJson(
Object? ruleIndex, [RuleIndex? defaultValue]) → RuleIndex -
ruleIndexListFromJson(
List? ruleIndex, [List< RuleIndex> ? defaultValue]) → List<RuleIndex> -
ruleIndexListToJson(
List< RuleIndex> ? ruleIndex) → List<String> -
ruleIndexNullableFromJson(
Object? ruleIndex, [RuleIndex? defaultValue]) → RuleIndex? -
ruleIndexNullableListFromJson(
List? ruleIndex, [List< RuleIndex> ? defaultValue]) → List<RuleIndex> ? -
ruleIndexNullableToJson(
RuleIndex? ruleIndex) → String? -
ruleIndexToJson(
RuleIndex ruleIndex) → String? -
ruleSectionIndexExplodedListToJson(
List< RuleSectionIndex> ? ruleSectionIndex) → String -
ruleSectionIndexFromJson(
Object? ruleSectionIndex, [RuleSectionIndex? defaultValue]) → RuleSectionIndex -
ruleSectionIndexListFromJson(
List? ruleSectionIndex, [List< RuleSectionIndex> ? defaultValue]) → List<RuleSectionIndex> -
ruleSectionIndexListToJson(
List< RuleSectionIndex> ? ruleSectionIndex) → List<String> -
ruleSectionIndexNullableFromJson(
Object? ruleSectionIndex, [RuleSectionIndex? defaultValue]) → RuleSectionIndex? -
ruleSectionIndexNullableListFromJson(
List? ruleSectionIndex, [List< RuleSectionIndex> ? defaultValue]) → List<RuleSectionIndex> ? -
ruleSectionIndexNullableToJson(
RuleSectionIndex? ruleSectionIndex) → String? -
ruleSectionIndexToJson(
RuleSectionIndex ruleSectionIndex) → String? -
skillIndexExplodedListToJson(
List< SkillIndex> ? skillIndex) → String -
skillIndexFromJson(
Object? skillIndex, [SkillIndex? defaultValue]) → SkillIndex -
skillIndexListFromJson(
List? skillIndex, [List< SkillIndex> ? defaultValue]) → List<SkillIndex> -
skillIndexListToJson(
List< SkillIndex> ? skillIndex) → List<String> -
skillIndexNullableFromJson(
Object? skillIndex, [SkillIndex? defaultValue]) → SkillIndex? -
skillIndexNullableListFromJson(
List? skillIndex, [List< SkillIndex> ? defaultValue]) → List<SkillIndex> ? -
skillIndexNullableToJson(
SkillIndex? skillIndex) → String? -
skillIndexToJson(
SkillIndex skillIndex) → String? -
spellComponentsExplodedListToJson(
List< SpellComponents> ? spellComponents) → String -
spellComponentsFromJson(
Object? spellComponents, [SpellComponents? defaultValue]) → SpellComponents -
spellComponentsListFromJson(
List? spellComponents, [List< SpellComponents> ? defaultValue]) → List<SpellComponents> -
spellComponentsListToJson(
List< SpellComponents> ? spellComponents) → List<String> -
spellComponentsNullableFromJson(
Object? spellComponents, [SpellComponents? defaultValue]) → SpellComponents? -
spellComponentsNullableListFromJson(
List? spellComponents, [List< SpellComponents> ? defaultValue]) → List<SpellComponents> ? -
spellComponentsNullableToJson(
SpellComponents? spellComponents) → String? -
spellComponentsToJson(
SpellComponents spellComponents) → String? -
subclassIndexExplodedListToJson(
List< SubclassIndex> ? subclassIndex) → String -
subclassIndexFromJson(
Object? subclassIndex, [SubclassIndex? defaultValue]) → SubclassIndex -
subclassIndexListFromJson(
List? subclassIndex, [List< SubclassIndex> ? defaultValue]) → List<SubclassIndex> -
subclassIndexListToJson(
List< SubclassIndex> ? subclassIndex) → List<String> -
subclassIndexNullableFromJson(
Object? subclassIndex, [SubclassIndex? defaultValue]) → SubclassIndex? -
subclassIndexNullableListFromJson(
List? subclassIndex, [List< SubclassIndex> ? defaultValue]) → List<SubclassIndex> ? -
subclassIndexNullableToJson(
SubclassIndex? subclassIndex) → String? -
subclassIndexToJson(
SubclassIndex subclassIndex) → String? -
subraceIndexExplodedListToJson(
List< SubraceIndex> ? subraceIndex) → String -
subraceIndexFromJson(
Object? subraceIndex, [SubraceIndex? defaultValue]) → SubraceIndex -
subraceIndexListFromJson(
List? subraceIndex, [List< SubraceIndex> ? defaultValue]) → List<SubraceIndex> -
subraceIndexListToJson(
List< SubraceIndex> ? subraceIndex) → List<String> -
subraceIndexNullableFromJson(
Object? subraceIndex, [SubraceIndex? defaultValue]) → SubraceIndex? -
subraceIndexNullableListFromJson(
List? subraceIndex, [List< SubraceIndex> ? defaultValue]) → List<SubraceIndex> ? -
subraceIndexNullableToJson(
SubraceIndex? subraceIndex) → String? -
subraceIndexToJson(
SubraceIndex subraceIndex) → String? -
traitIndexExplodedListToJson(
List< TraitIndex> ? traitIndex) → String -
traitIndexFromJson(
Object? traitIndex, [TraitIndex? defaultValue]) → TraitIndex -
traitIndexListFromJson(
List? traitIndex, [List< TraitIndex> ? defaultValue]) → List<TraitIndex> -
traitIndexListToJson(
List< TraitIndex> ? traitIndex) → List<String> -
traitIndexNullableFromJson(
Object? traitIndex, [TraitIndex? defaultValue]) → TraitIndex? -
traitIndexNullableListFromJson(
List? traitIndex, [List< TraitIndex> ? defaultValue]) → List<TraitIndex> ? -
traitIndexNullableToJson(
TraitIndex? traitIndex) → String? -
traitIndexToJson(
TraitIndex traitIndex) → String? -
weaponPropertyIndexExplodedListToJson(
List< WeaponPropertyIndex> ? weaponPropertyIndex) → String -
weaponPropertyIndexFromJson(
Object? weaponPropertyIndex, [WeaponPropertyIndex? defaultValue]) → WeaponPropertyIndex -
weaponPropertyIndexListFromJson(
List? weaponPropertyIndex, [List< WeaponPropertyIndex> ? defaultValue]) → List<WeaponPropertyIndex> -
weaponPropertyIndexListToJson(
List< WeaponPropertyIndex> ? weaponPropertyIndex) → List<String> -
weaponPropertyIndexNullableFromJson(
Object? weaponPropertyIndex, [WeaponPropertyIndex? defaultValue]) → WeaponPropertyIndex? -
weaponPropertyIndexNullableListFromJson(
List? weaponPropertyIndex, [List< WeaponPropertyIndex> ? defaultValue]) → List<WeaponPropertyIndex> ? -
weaponPropertyIndexNullableToJson(
WeaponPropertyIndex? weaponPropertyIndex) → String? -
weaponPropertyIndexToJson(
WeaponPropertyIndex weaponPropertyIndex) → String?