AbilityScore class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

AbilityScore({String? fullName, List<APIReference>? skills, String? index, String? name, String? url, String? updatedAt, List<String>? desc})
const
AbilityScore.fromJson(Map<String, dynamic> json)
factory

Properties

desc List<String>?
final
fullName String?
final
hashCode int
The hash code for this object.
no setteroverride
index String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skills List<APIReference>?
final
updatedAt String?
final
url String?
final

Methods

copyWith({String? fullName, List<APIReference>? skills, String? index, String? name, String? url, String? updatedAt, List<String>? desc}) AbilityScore

Available on AbilityScore, provided by the $AbilityScoreExtension extension

copyWithWrapped({Wrapped<String?>? fullName, Wrapped<List<APIReference>?>? skills, Wrapped<String?>? index, Wrapped<String?>? name, Wrapped<String?>? url, Wrapped<String?>? updatedAt, Wrapped<List<String>?>? desc}) AbilityScore

Available on AbilityScore, provided by the $AbilityScoreExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const AbilityScore Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(AbilityScore instance)