AlignmentIndex enum

Inheritance
Available extensions

Values

swaggerGeneratedUnknown → const AlignmentIndex
const AlignmentIndex(null)
chaoticNeutral → const AlignmentIndex
const AlignmentIndex('chaotic-neutral')
chaoticEvil → const AlignmentIndex
const AlignmentIndex('chaotic-evil')
chaoticGood → const AlignmentIndex
const AlignmentIndex('chaotic-good')
lawfulNeutral → const AlignmentIndex
const AlignmentIndex('lawful-neutral')
lawfulEvil → const AlignmentIndex
const AlignmentIndex('lawful-evil')
lawfulGood → const AlignmentIndex
const AlignmentIndex('lawful-good')
neutral → const AlignmentIndex
const AlignmentIndex('neutral')
neutralEvil → const AlignmentIndex
const AlignmentIndex('neutral-evil')
neutralGood → const AlignmentIndex
const AlignmentIndex('neutral-good')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AlignmentIndex>
A constant List of the values in this enum, in order of their declaration.