Feat class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Feat({List<Prerequisite>? prerequisites, String? index, String? name, String? url, String? updatedAt, List<String>? desc})
const
Feat.fromJson(Map<String, dynamic> json)
factory

Properties

desc List<String>?
final
hashCode int
The hash code for this object.
no setteroverride
index String?
final
name String?
final
prerequisites List<Prerequisite>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt String?
final
url String?
final

Methods

copyWith({List<Prerequisite>? prerequisites, String? index, String? name, String? url, String? updatedAt, List<String>? desc}) Feat

Available on Feat, provided by the $FeatExtension extension

copyWithWrapped({Wrapped<List<Prerequisite>?>? prerequisites, Wrapped<String?>? index, Wrapped<String?>? name, Wrapped<String?>? url, Wrapped<String?>? updatedAt, Wrapped<List<String>?>? desc}) Feat

Available on Feat, provided by the $FeatExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const Feat Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Feat instance)