MonsterSpell class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

MonsterSpell({String? name, double? level, String? url, MonsterUsage? usage})
const
MonsterSpell.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
level double?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final
usage MonsterUsage?
final

Methods

copyWith({String? name, double? level, String? url, MonsterUsage? usage}) MonsterSpell

Available on MonsterSpell, provided by the $MonsterSpellExtension extension

copyWithWrapped({Wrapped<String?>? name, Wrapped<double?>? level, Wrapped<String?>? url, Wrapped<MonsterUsage?>? usage}) MonsterSpell

Available on MonsterSpell, provided by the $MonsterSpellExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const MonsterSpell Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(MonsterSpell instance)