Weapon$Range class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true)

Constructors

Weapon$Range({double? normal, double? long})
const
Weapon$Range.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
long double?
final
normal double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? normal, double? long}) Weapon$Range

Available on Weapon$Range, provided by the $Weapon$RangeExtension extension

copyWithWrapped({Wrapped<double?>? normal, Wrapped<double?>? long}) Weapon$Range

Available on Weapon$Range, provided by the $Weapon$RangeExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

fromJsonFactory → const Weapon$Range Function(Map<String, dynamic> json)
toJsonFactory → const Map<String, dynamic> Function(Weapon$Range instance)