WeaponPropertyIndex enum

Inheritance
Available extensions

Values

swaggerGeneratedUnknown → const WeaponPropertyIndex
const WeaponPropertyIndex(null)
ammunition → const WeaponPropertyIndex
const WeaponPropertyIndex('ammunition')
finesse → const WeaponPropertyIndex
const WeaponPropertyIndex('finesse')
heavy → const WeaponPropertyIndex
const WeaponPropertyIndex('heavy')
light → const WeaponPropertyIndex
const WeaponPropertyIndex('light')
loading → const WeaponPropertyIndex
const WeaponPropertyIndex('loading')
monk → const WeaponPropertyIndex
const WeaponPropertyIndex('monk')
reach → const WeaponPropertyIndex
const WeaponPropertyIndex('reach')
special → const WeaponPropertyIndex
const WeaponPropertyIndex('special')
thrown → const WeaponPropertyIndex
const WeaponPropertyIndex('thrown')
twoHanded → const WeaponPropertyIndex
const WeaponPropertyIndex('two-handed')
versatile → const WeaponPropertyIndex
const WeaponPropertyIndex('versatile')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<WeaponPropertyIndex>
A constant List of the values in this enum, in order of their declaration.